@@ -82,6 +82,7 @@ FILE *fp;
 	    break;
 	}
     }
+    if (fi.type == 0xff) fi.type = CodingByRegistry("ISO8859-1");
     fi.width = width;
     fi.high = high;
     if (fi.type & CHR_DBC) {
@@ -97,7 +98,7 @@ FILE *fp;
 	fldReg = &fldSRegs[fi.type&~CHR_SFLD];
 	fReg = &fSRegs[fi.type&~CHR_SFLD];
 	if (fldReg->max)
-	    fi.size = fldReg->max * 16;
+	    fi.size = (fldReg->max + 1) * 16;
 	else
 	    fi.size = num * 16;
     }
@@ -158,5 +159,6 @@ void main(int argc, char *argv[])
 
     fp = fopen(argv[1], "r");
     FontLoadBdf(fp);
+    exit(0);
 }
 #endif
