@@ -31,9 +31,9 @@
 
 extern void	Perror(const char *message);		/* perror(message) */
 extern void	PerrorExit(const char *message);	/* perror(message) and die */
-extern void	fatal(const char *format, ...);		/* print error message and die */
-extern void	error(const char *format, ...);		/* print error message */
-extern void	warn(const char *format, ...);		/* print warning message */
-extern void	message(const char *format, ...);	/* print message */
+extern void	KonFatal(const char *format, ...);	/* print error message and die */
+extern void	KonError(const char *format, ...);	/* print error message */
+extern void	KonWarn(const char *format, ...);	/* print warning message */
+extern void	KonMessage(const char *format, ...);	/* print message */
 
 #endif
