@@ -31,6 +31,7 @@
 #define	FNLD_H
 
 #include <interface.h>
+#include <defs.h>
 
 struct fontRegs {
     u_int (*addr)(u_char ch1, u_char ch2);
@@ -57,5 +58,8 @@ extern struct fontRegs *sbFReg, *dbFReg;
 extern u_char	*FontLoad(u_char *fbuff, int fd, struct fontInfo *fi);
 extern u_char	*GetShmem(char type);
 extern void	DownShmem(char type);
+extern void	FontAttach(void);
+extern void	FontDetach(bool);
+extern int	CodingByRegistry(char *);
 
 #endif
