@@ -54,6 +54,10 @@ struct _con_info {
 	CS_RIGHT,
 	CS_GRAPH,
 	CS_DBCS} trans, g[2];
+    enum {
+	SL_NONE,
+	SL_ENTER,
+	SL_LEAVE} sl;
     bool
 	soft,
 	ins,
