@@ -57,6 +57,12 @@
 #include	<vga.h>
 #include	<fnld.h>
 
+#ifdef	MINI_KON
+#define	vgaCrtAddr	0x3D4
+#define	vgaCrtData	0x3D5
+#define	vgaSt1Addr	0x3DA
+#endif
+
 static
     void SvgaSetStartAddress(void)
 {
