@@ -86,22 +86,30 @@ struct vgaRegs
     };
 
 int LineComp9, LineComp8, gramHead;
+#ifdef	MINI_KON
+#define	vgaCrtAddr	0x3D4
+#define	vgaCrtData	0x3D5
+#define	vgaSt1Addr	0x3DA
+#else
 u_int vgaCrtAddr = 0x3D4;
 u_int vgaCrtData = 0x3D5;
 u_int vgaSt1Addr = 0x3DA;
+#endif
 
 static	char	*gramMem;		/* dummy buffer for mmapping grahics memory */
 static	char	*fontBuff1;		/* saved font data - plane 2 */
 
+static	bool	savePlane3;
 static	char	*fontBuff2;		/* saved font data - plane 3 */
 
 static	u_int	writeAddr;		 /* address to write next character */
 
 static	bool	kanjiCursor;
 static	u_char	cursorTop, cursorBtm;
-static	bool	savePlane3;
 
+#ifndef	MINI_KON
 static	u_short	fmPattern;		 /* bit pattern to modify font; skip line if bit clear */
+#endif
 
 void VgaSetRegisters(struct vgaRegs *regs)
 {
@@ -227,7 +235,11 @@ void VgaInit(void)
 #ifdef	USE_ROMFONT
     VgaLoadRomFont(fontBuff1);
 #endif
-    if (savePlane3) {
+#if defined(MINI_KON) || defined(USE_STATICFONT)
+    VgaLoadStaticFont();
+#endif
+
+    if (savePlane3 && fontBuff2) {
 	/* save font data in plane 3 */
 	PortOutw(0x0304, VGAGRP_ADDR);
 	memcpy(fontBuff2, gramMem, FONT_SIZE);
@@ -288,6 +300,20 @@ void VgaGraphMode(void)
     PortOutb(0x20, VGAATTR_A_O);
 }
 
+#ifdef	MINI_KON
+void VgaChangeClock()
+{
+    static int clock=-1;
+
+    if (clock < 0) clock = (regGraph.mis >> 2) & 3;
+    clock = (clock + 1) & 3;
+    regGraph.mis &= ~(3 << 2);
+    regGraph.mis |= clock << 2;
+printf("%d\r\n", clock);
+    VgaGraphMode();
+}    
+#endif
+
 void VgaWput(u_char *code, u_char fc, u_char bc)
 {
     volatile char	*gram, *vcls;
@@ -407,17 +433,17 @@ void VgaHardScrollUp(int line)
     
     if (line > dInfo.tymax) {
 	line %= dInfo.tymax + 1;
-	lzero(gramMem, dInfo.gsize);
+	bzero(gramMem, dInfo.gsize);
     }
     
     oldhead = gramHead;
     gramHead += line * dInfo.tlineByte;
     if (gramHead >= dInfo.gsize) {
 	gramHead -= dInfo.gsize;
-	lzero(gramMem + oldhead, dInfo.gsize - oldhead);
-/*	if (gramHead) lzero(gramMem, gramHead);*/
-	lzero(gramMem, gramHead);
-    } else lzero(gramMem + oldhead, gramHead - oldhead);
+	bzero(gramMem + oldhead, dInfo.gsize - oldhead);
+/*	if (gramHead) bzero(gramMem, gramHead);*/
+	bzero(gramMem, gramHead);
+    } else bzero(gramMem + oldhead, gramHead - oldhead);
     vInfo.set_start_address();
 }
 
@@ -429,17 +455,17 @@ void VgaHardScrollDown(int line)
     
     if (line > dInfo.tymax) {
 	line %= dInfo.tymax + 1;
-	lzero(gramMem, dInfo.gsize);
+	bzero(gramMem, dInfo.gsize);
     }
     
     oldhead = gramHead;
     gramHead -= line * dInfo.tlineByte;
     if (gramHead < 0) {
 	gramHead += dInfo.gsize;
-/*	if (oldhead) lzero(gramMem, oldhead);*/
-	lzero(gramMem, oldhead);
-	lzero(gramMem + gramHead, dInfo.gsize - gramHead);
-    } else lzero(gramMem + gramHead, oldhead - gramHead);
+/*	if (oldhead) bzero(gramMem, oldhead);*/
+	bzero(gramMem, oldhead);
+	bzero(gramMem + gramHead, dInfo.gsize - gramHead);
+    } else bzero(gramMem + gramHead, oldhead - gramHead);
     vInfo.set_start_address();
 }
 
@@ -487,7 +513,7 @@ void VgaCursor(struct cursorInfo *ci)
 void VgaClearAll(void)
 {
     VgaSetColor((con.attr & ATTR_REVERSE ? con.fcol:con.bcol)&7);
-    lzero(gramMem, dInfo.gsize);
+    bzero(gramMem, dInfo.gsize);
 }
 
 void VgaScreenSaver(bool blank)
@@ -508,7 +534,7 @@ int VgaReadPels(const char *str)
     for (i = 0; i < MAX_PELS; i ++) {
 	sscanf(str, "%d %d %d", &red, &grn, &blu);
 	if ((str = strchr(str, '\n')) == NULL) {
-	    error("PELS entry too short\r\n");
+	    KonError("PELS entry too short\r\n");
 	    return FAILURE;
 	}
 	str++;			/* skip '\n' */
@@ -526,7 +552,7 @@ int VgaReadNewRegs(const char *str, union videoTimings *video)
 
     for (i = 0; i < NUM_VIDEOH_INFO+NUM_VIDEOV_INFO; i ++) {
         if (! *str) {
-	    error("%d values required for vga registers, "
+	    KonError("%d values required for vga registers, "
 		  "but only supplied %d\r\n", VGACRT_CNT, i);
 	    return FAILURE;
 	}
@@ -536,7 +562,7 @@ int VgaReadNewRegs(const char *str, union videoTimings *video)
     *line2 = '\0';line2 ++;
     if (*str) video->m.i = atoi(str);
     if (sscanf(line2, "%x \n %d %d", &clock, &txmax, &tymax) == EOF) {
-	error("missing arg for vga driver\r\n");
+	KonError("missing arg for vga driver\r\n");
 	return FAILURE;
     }
     dInfo.gxdim = video->m.hDot;
@@ -597,11 +623,13 @@ int VgaAttach(void)
 
 #if defined(linux)
     ioperm(VGAMISC_IN, 1, 1);
+#ifndef	MINI_KON
     if (!(PortInb(VGAMISC_IN)&0x01)) { /* monochrome VGA */
 	vgaCrtAddr = 0x3B4;
 	vgaCrtData = 0x3B5;
 	vgaSt1Addr = 0x3BA;
     }
+#endif
     
     /* get I/O permissions for VGA registers */
     ioperm(vgaCrtAddr, 1, 1);
@@ -620,26 +648,27 @@ int VgaAttach(void)
     ioperm(VGAPAL_DATA, 1, 1);
 
     if ((devMem = open("/dev/mem", O_RDWR) ) < 0) {
-	Perror("/dev/mem");
+	perror("/dev/mem");
 	return FAILURE;
     }
 #elif defined(__FreeBSD__)
     if (ioctl(0, KDENABIO,0) < 0) {
-	Perror("ioctl CONSOLE_IO_ENABLE");
+	perror("ioctl CONSOLE_IO_ENABLE");
 	return FAILURE;
     }
     if (ioctl(0, KDSETMODE,KD_GRAPHICS) < 0) {
-	Perror("ioctl CONSOLE_IO_ENABLE");
+	perror("ioctl CONSOLE_IO_ENABLE");
 	return FAILURE;
     }
     if ((devMem = open("/dev/vga", O_RDWR|O_NDELAY) ) < 0) {
-	Perror("/dev/mem");
+	perror("/dev/mem");
 	return FAILURE;
     }
 #endif
-    if ((fontBuff1 = malloc(FONT_SIZE)) == NULL ||
-	(savePlane3 && (fontBuff2 = malloc(FONT_SIZE)) == NULL)) {
-	Perror("malloc ");
+    if ((fontBuff1 = malloc(FONT_SIZE)) == NULL
+	|| (savePlane3 && (fontBuff2 = malloc(FONT_SIZE)) == NULL)
+	) {
+	perror("malloc ");
 	return FAILURE;
     }
     gramMem = (unsigned char *)mmap(
@@ -664,7 +693,7 @@ int VgaAttach(void)
 				    );
     close(devMem);
     if ((long)gramMem < 0) {
-	Perror("mmap");
+	perror("mmap");
 	return FAILURE;
     }
     
@@ -695,7 +724,7 @@ void VgaDetach(void)
     
     SafeFree((void **)&gramMem);
     SafeFree((void **)&fontBuff1);
-    if (savePlane3)
+    if (savePlane3 && fontBuff2)
 	SafeFree((void **)&fontBuff2);
 }
 
