@@ -24,6 +24,7 @@
  * SUCH DAMAGE.
  * 
  */
+#include	<config.h>
 
 #include	<stdio.h>
 #include	<errno.h>
@@ -41,6 +42,7 @@
 
 static void KonPrintf(const char *head, const char *format, va_list args)
 {
+#ifndef MINI_KON
 	char buf[MAX_MSGLEN];
 
 	if (con.text_mode) {
@@ -51,20 +53,23 @@ static void KonPrintf(const char *head, const char *format, va_list args)
 		vsprintf(buf, format, args);
 		VtEmu(buf, strlen(buf));
 	}
+#endif
 }
 
-void fatal(const char *format, ...)
+void KonFatal(const char *format, ...)
 {
+#ifndef MINI_KON
 	va_list args;
 
 	va_start(args, format);
 	fprintf(stderr, "KON> fatal error: ");
 	vfprintf(stderr, format, args);
 	va_end(args);
+#endif
 	exit(EXIT_FAILURE);
 }
 
-void warn(const char *format, ...)
+void KonWarn(const char *format, ...)
 {
 	va_list args;
 
@@ -73,31 +78,39 @@ void warn(const char *format, ...)
 	va_end(args);
 }
 
-void error(const char *format, ...)
+void KonError(const char *format, ...)
 {
+#ifndef MINI_KON
 	va_list args;
 
 	va_start(args, format);
 	KonPrintf("KON> error: ", format, args);
 	va_end(args);
+#endif
 }
 
-void message(const char *format, ...)
+void KonMessage(const char *format, ...)
 {
+#ifndef MINI_KON
 	va_list args;
 
 	va_start(args, format);
 	KonPrintf("KON> ", format, args);
 	va_end(args);
+#endif
 }
 
 void Perror(const char *msg)
 {
-	message("system error - %s: %s\r\n", msg, strerror(errno));
+#ifndef MINI_KON
+	KonMessage("system error - %s: %s\r\n", msg, strerror(errno));
+#endif
 }
 
 void PerrorExit(const char *message)
 {
+#ifndef MINI_KON
 	fprintf(stderr, "%s: %s\r\n", message, strerror(errno));
+#endif
 	exit(EXIT_FAILURE);
 }
