@@ -33,6 +33,10 @@
 	Thanks to komeda@ics.osaka-u.ac.jp.
 */
 
+#include <config.h>
+
+#ifndef	MINI_KON
+
 #include	<stdio.h>
 #include	<unistd.h>
 #include	<fcntl.h>
@@ -97,3 +101,4 @@ void	ResetUtmp(char *tty)
 	chown(tty, 0, ttyGid);
 #endif
 }
+#endif	/* MINI_KON */
