@@ -8,24 +8,39 @@ struct _fontent {
     unsigned char bitmap[32];
 } fent[65535];
 
-void
-main()
+int
+main(int argc, char *argv[])
 {
+    bool all=FALSE;
     unsigned short code, max=0;
     unsigned int fnt, i, num=0;
-    unsigned char line[10], *font, bytes, high;
-    struct fontInfo *fi;
+    unsigned char line[10], *path, *font, bytes, high;
     struct fontRegs *freg=&fDRegs[1];
+    extern struct fontInfo fi;
 
-    if ((font = GetShmem(1|CHR_DFLD)) == NULL) {
-	perror("GetShmem");
-	exit(-1);
+    path = NULL;
+    for (i = 1; i < argc; i ++) {
+  	if (*argv[i] == '-') {
+	    if (*(argv[i] + 1) == 'a') all = TRUE;
+	} else path = argv[i];
     }
-    fi = (struct fontInfo *)font;
-    high = fi->high;
+    if (!path) {
+	printf("usage: %s [minix font file]\n");
+	exit(1);
+    }
+    if ((font = LoadFontFile(path, "minix", 0)) == NULL) {
+	perror(argv[1]);
+	exit(1);
+    }
+    high = fi.high;
     bytes = sizeof(fent[0].code) + high * 2;
-    font += sizeof(struct fontInfo);
-    while (fgets(line, sizeof(line), stdin)) {
+    if (all) for (num = 0x2121; num < 0x7474; num ++) {
+        code = num & 0x7F7F;
+	if (code > max) max = code;
+	fnt = freg->addr((code >> 8) & 0x7F, code & 0x7F);
+	fent[code].code = code;
+	memcpy(fent[code].bitmap, font + fnt, 32);
+    } else while (fgets(line, sizeof(line), stdin)) {
 	code = ((line[0] << 8) & 0x7F00) | (line[1] & 0x7F);
 	if (code > max) max = code;
 	fnt = freg->addr(line[0] & 0x7F, line[1] & 0x7F);
@@ -37,4 +52,5 @@ main()
     fwrite(&max, sizeof(max), 1, stdout);
     for (i = 0; i < num; i ++) if (fent[i].code)
 	fwrite(&fent[i], bytes, 1, stdout);
+    return(0);
 }
